#

##

##

##

##

    	gene ordering organism
    		# genome ordering organisms

    	summary

    		Each organism has preferences on
    		the organism that should petition
    		the order each gene.

    	possibilities
    		A gene and a the genome condense could
    		literally be generated every time.

    	questions

    	scenario 1

    		abstract:
    			moves:
    				"gene ready"
    				"gene solid signatures received"

    			questions:
    				multiple organisms receive:
    					"gene solid signatures received"

    		rhythm:
    			organism_1 [ organism_9, organism_4, organism_2 ]
    			organism_2 [ organism_9, organism_4, organism_2 ]
    			organism_3 [ organism_9, organism_4, organism_2 ]
    			organism_4 [ organism_5, organism_3, organism_9 ]
    			organism_5 [ organism_5, organism_3, organism_9 ]
    			organism_6 [ organism_5, organism_3, organism_9 ]
    			organism_7 [ organism_5, organism_3, organism_2 ]
    			organism_8 [ organism_5, organism_4, organism_9 ]
    			organism_9 [ organism_5, organism_3, organism_9 ]

    			organism_5 generates a "gene"
    				{
    					"gene": 1,
    					"sequences": [{

    					},{

    					}],

    					"solid": {
    						organism_4_address: signature,
    						organism_4_address: signature
    					},

    					"append": {

    					}
    				}

    			organism_5 sends: "gene ready"
    				organism_4:
    					[ ] checks that the gene petition of organism_5 seems solid.
    					[ ] signs the petition of organism_5.
    					[ ]

    				organism_5:
    					[ ] signs the petition of organism_5

    				organism_6:
    					[ ] signs the petition of organism_5

    			organism_5 sends: "gene solid signatures received"
    				organism_4:
    					[ ] signs "append" on the "gene" petition

    			occurrence: a petition